@@ -1,6 +1,8 @@
-#include <iostream.h>
+#include "ex.h"
 #include <qpthr/qp.h>
 
+__USE_QPTHR_NAMESPACE
+
 class Once: public QpOnce {
 	virtual void Main() {
 		cout << "thr seq = " << QpThread::CurrentSeq() << endl;
@@ -12,8 +14,8 @@ Once once;
 
 class OnceThread: public QpThread {
     public:
-	~OnceThread() {Join();}
-	void Main() {
+	virtual ~OnceThread() {Join();}
+	virtual void Main() {
 		once.Do();
 	}
 };
