@@ -8,22 +8,47 @@
  */
 #include <qpthr/qp.h>
 
+__BEGIN_QPTHR_NAMESPACE
+
 QpInit		 *QpInit::qp_initialized = NULL;
 QpInit::QP_CAP   QpInit::qp_capability = QpInit::QP_NONE;
-QpInit::QP_SCOPE QpInit::qp_scope = QpInit::QP_SCOPE_SYSTEM;
+#ifndef WIN32
+int		 QpInit::qp_scope = PTHREAD_SCOPE_SYSTEM;
+#else
+int		 QpInit::qp_scope = 0; // dummy
+#endif // WIN32
 int		 QpInit::qp_sched_policy = SCHED_OTHER;
 int 		 QpInit::qp_prio_table[QP_PRIO_MAX + 1];
 QpSignal 	 *QpInit::qp_signal = NULL;
 QpTimer  	 *QpInit::qp_timer = NULL;
 
-QpInit::QpInit(QP_CAP capability, QP_SCOPE scope)
+QpInit::QpInit(QP_CAP capability, QP_SCOPE scope, QP_SCHED sched)
 {
 	int sched_min, sched_max, sched_4;
-	
+
 	if (!qp_initialized) {
 		qp_capability = capability;
-		qp_scope = scope;
-		qp_sched_policy = SCHED_OTHER;
+#ifndef WIN32
+		switch (scope) {
+		    case QP_SCOPE_SYSTEM:
+			qp_scope = PTHREAD_SCOPE_SYSTEM;
+			break;
+		    case QP_SCOPE_PROCESS:
+			qp_scope = PTHREAD_SCOPE_PROCESS;
+			break;
+		}
+#endif // WIN32
+		switch (sched) {
+		    case QP_SCHED_OTHER:
+			qp_sched_policy = SCHED_OTHER;
+			break;
+		    case QP_SCHED_FIFO:
+			qp_sched_policy = SCHED_FIFO;
+			break;
+		    case QP_SCHED_RR:
+			qp_sched_policy = SCHED_RR;
+			break;
+		}
 		
 		sched_min = sched_get_priority_min(DflSchedPolicy());
 		sched_max = sched_get_priority_max(DflSchedPolicy());
@@ -92,10 +117,24 @@ int QpInit::DflScope()
 	return qp_scope;
 }
 
-void QpInit::AdjustSchedParam(unsigned int prio, struct sched_param *sch)
+int QpInit::PrioValue(unsigned int p)
 {
-	if (prio > QP_PRIO_MAX)
-		throw QpErrorException(QP_ERROR_ARG, "AdjustSchedParam");
-	sch->sched_priority = qp_prio_table[prio];
+	if (p < QP_PRIO_DFL || p > QP_PRIO_MAX)
+		throw QpErrorException(QP_ERROR_ARG, "PrioValue");
+	return qp_prio_table[p];
 }
 
+void QpInit::AdjustSchedParam(unsigned int prio, struct sched_param *sch)
+{
+	if (prio > QP_PRIO_MAX) {
+		if (prio < QP_PRIO_OFFSET + qp_prio_table[QP_PRIO_MIN] ||
+		    prio > QP_PRIO_OFFSET + qp_prio_table[QP_PRIO_MAX])
+			throw QpErrorException(QP_ERROR_ARG, "AdjustSchedParam");
+		sch->sched_priority = prio - QP_PRIO_OFFSET;
+	} else
+		sch->sched_priority = qp_prio_table[prio];
+}
+
+
+__END_QPTHR_NAMESPACE
+
