@@ -8,11 +8,13 @@
  */
 #include <qpthr/qp.h>
 
+__BEGIN_QPTHR_NAMESPACE
+
 const unsigned int QpTimer::TIMERJOB_MAGIC = 0xAB23AB33;
 QpMutex		  QpTimer::t_mutex;
 QpCond		  QpTimer::t_timer_cond(&QpTimer::t_mutex);
 #if ! (defined(__SUNPRO_CC) && (__SUNPRO_CC <= 0x420))
-list<QpTimer::TimerJob *>  QpTimer::t_job_list;
+QpTimer::TimerJobList      QpTimer::t_job_list;
 QpTimer::QpTimerThread	  *QpTimer::t_timer_thread;
 #else
 list<TimerJob *>	  QpTimer::t_job_list;
@@ -43,7 +45,7 @@ QpTimer::~QpTimer()
 	t_timer_thread = NULL;
 }
 
-static void CheckCapability(char *msg)
+static void CheckCapability(const char *msg)
 {
 	if (!QpInit::Capability(QpInit::QP_TIMER))
 		throw QpErrorException(QP_ERROR_DISABLED, msg);
@@ -212,3 +214,5 @@ QpThread *QpTimer::TimerThread()
 	return t_timer_thread;
 }
 
+__END_QPTHR_NAMESPACE
+
