@@ -11,6 +11,8 @@
 
 #include <signal.h>
 
+__BEGIN_QPTHR_NAMESPACE
+
 class QpThread;
 class QpRunnable;
 class QpSignal;
@@ -114,4 +116,6 @@ class QpSignal {
 	QpSignal& operator = (const QpSignal&);
 };
 
+__END_QPTHR_NAMESPACE
+
 #endif
